@@ -10,11 +10,11 @@ Vim::Snippet::Converter - A Template Converter for Slippery Snippet Vim Plugin
 
 =head1 VERSION
 
-Version 0.08
+Version 0.082
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.082';
 
 =head1 SYNOPSIS
 
@@ -70,7 +70,7 @@ save triggers into vim completion file:
 
     $ scc -s perl.snt -c vim_completion
 
-append the below setting to your .vimrc , it is located in your home directory.
+append the below setting to your F<.vimrc> , it is located in your home directory.
 
     set dictionary+=/path/to/vim_completion
 
@@ -86,9 +86,15 @@ when you want to call the keyword completion , just press C<Ctrl-X Ctrl-K> in In
     }
     ;end
 
-'sub' is a trigger name , when you press <Tab> , the trigger will be replaced with the template.
+C<sub> is a trigger name , when you press C<E<lt>TabE<gt>> , the trigger will be replaced with the template.
 
-<<function>> is called Place Holder , when you press <Tab> again , curosr will jump to the next position to let you enter some text.
+C<E<lt>E<lt>functionE<gt>E<gt>> is called Place Holder , when you press
+C<E<lt>TabE<gt>> again , curosr will jump to the next position to let you enter
+some text.
+
+=head1 FUNCTIONS
+
+=head2 new
 
 =cut
 
@@ -97,12 +103,18 @@ sub new {
     return bless {} , $class;
 }
 
+=head2 convert
+
+=cut
 
 sub convert {
     my ( $self , $in , $out ) = @_;
     $self->parse( $in , $out );
 }
 
+=head2 _gen_trigger
+
+=cut
 
 sub _gen_trigger {
     my $self = shift;
@@ -114,6 +126,10 @@ sub _gen_trigger {
     return $output;
 }
 
+=head2 _gen_snippet
+
+=cut
+
 sub _gen_snippet {
     my $self = shift;
     my $buf  = shift;
@@ -132,6 +148,10 @@ sub _gen_snippet {
     return $buf;
 }
 
+=head2 parse
+
+=cut
+
 sub parse {
     my ( $self , $in , $out ) = @_;
 
@@ -162,6 +182,10 @@ sub parse {
     }
 }
 
+=head2 gen_header 
+
+=cut
+
 sub gen_header {
 	return <<EOF;
 if !exists('loaded_snippet') || &cp
@@ -195,7 +219,7 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
-=over 6
+=over 4
 
 =item * Vim
 
